@@ -1,16 +1,15 @@
-#
+# 
 # This file is part of Dist-Zilla-Plugin-Subversion
-#
+# 
 # This software is copyright (c) 2010 by Mark Gardner.
-#
+# 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-#
+# 
 use strict;
 use Modern::Perl;
-
 package Dist::Zilla::Role::Subversion;
-our $VERSION = '1.100890';
+$Dist::Zilla::Role::Subversion::VERSION = '1.100900';
 
 # ABSTRACT: does Subversion actions for a distribution
 
@@ -27,19 +26,16 @@ use SVN::Client;
 use SVN::Wc;
 use namespace::autoclean;
 
+
 for my $attr (qw(svn_user svn_password)) {
     has $attr => (
         is        => 'ro',
         isa       => 'Str',
-        lazy      => 1,
         predicate => "_has_$attr",
-        default   => sub {
-            return $ARG[0]->zilla->dzil_app->config_for(
-                'Dist::Zilla::App::Command::release')->{$attr};
-        },
     );
 }
 
+
 has 'working_url' => (
     is         => 'ro',
     isa        => Uri,
@@ -163,6 +159,8 @@ sub _log_commit_info {
 no Moose::Role;
 1;
 
+
+
 =pod
 
 =head1 NAME
@@ -171,7 +169,7 @@ Dist::Zilla::Role::Subversion - does Subversion actions for a distribution
 
 =head1 VERSION
 
-version 1.100890
+version 1.100900
 
 =head1 DESCRIPTION
 
@@ -209,4 +207,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
+
